@@ -4,8 +4,10 @@ from .SpaceTimeVariogram import SpaceTimeVariogram
 from .Kriging import OrdinaryKriging
 from .MetricSpace import MetricSpace, MetricSpacePair
 from . import interfaces
+from . import data
+from . import util
 
 # set some stuff
-__version__ = '0.5.4'
+__version__ = '0.5.6'
 __author__ = 'Mirko Maelicke <mirko.maelicke@kit.edu>'
 __backend__ = 'matplotlib'
